@@ -5,8 +5,8 @@
  (#eq? @function "#match?"))
 
 ; highlight inheritance comments
-((query . (comment) @keyword.directive)
- (#match? @keyword.directive "^;\ +inherits *:"))
+(((comment) @keyword.directive)
+ (#match? @keyword.directive "^; +inherits *:"))
 
 [
   "("
@@ -16,6 +16,7 @@
 ] @punctuation.bracket
 
 ":" @punctuation.delimiter
+"!" @operator
 
 [
   (one_or_more)
@@ -35,12 +36,15 @@
 
 (comment) @comment
 
-(field_name) @property
+(field_name) @variable.other.member
 
 (capture) @label
 
-(predicate_name) @function
+((predicate_name) @function
+ (#match? @function "^#(eq\\?|match\\?|is\\?|is-not\\?|not-same-line\\?|not-kind-eq\\?|set!|select-adjacent!|strip!)$"))
+(predicate_name) @error
 
-(escape_sequence) @escape
+(escape_sequence) @constant.character.escape
 
-(node_name) @variable
+(node_name) @tag
+(variable) @variable
